pub struct SpiImplExchangeVmoRequest {
pub chip_select: u32,
pub tx_buffer: SharedVmoBuffer,
pub rx_buffer: SharedVmoBuffer,
}Fields
chip_select: u32tx_buffer: SharedVmoBufferrx_buffer: SharedVmoBufferTrait Implementations
Sourceimpl Clone for SpiImplExchangeVmoRequest
impl Clone for SpiImplExchangeVmoRequest
Sourcefn clone(&self) -> SpiImplExchangeVmoRequest
fn clone(&self) -> SpiImplExchangeVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplExchangeVmoRequest
impl Debug for SpiImplExchangeVmoRequest
Sourceimpl<'a, ___E> Encode<SpiImplExchangeVmoRequest, ___E> for &'a SpiImplExchangeVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplExchangeVmoRequest, ___E> for &'a SpiImplExchangeVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplExchangeVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplExchangeVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplExchangeVmoRequest, ___E> for SpiImplExchangeVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplExchangeVmoRequest, ___E> for SpiImplExchangeVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplExchangeVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplExchangeVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplExchangeVmoRequest>, ___E> for &'a SpiImplExchangeVmoRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplExchangeVmoRequest: Encode<SpiImplExchangeVmoRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SpiImplExchangeVmoRequest>, ___E> for &'a SpiImplExchangeVmoRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplExchangeVmoRequest: Encode<SpiImplExchangeVmoRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a SpiImplExchangeVmoRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplExchangeVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SpiImplExchangeVmoRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplExchangeVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplExchangeVmoRequest>, ___E> for SpiImplExchangeVmoRequest
impl<___E> EncodeOption<Box<'static, SpiImplExchangeVmoRequest>, ___E> for SpiImplExchangeVmoRequest
Sourcefn encode_option(
this: Option<SpiImplExchangeVmoRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplExchangeVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SpiImplExchangeVmoRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplExchangeVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplExchangeVmoRequest> for SpiImplExchangeVmoRequest
impl FromWire<SpiImplExchangeVmoRequest> for SpiImplExchangeVmoRequest
Sourcefn from_wire(wire: SpiImplExchangeVmoRequest) -> SpiImplExchangeVmoRequest
fn from_wire(wire: SpiImplExchangeVmoRequest) -> SpiImplExchangeVmoRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SpiImplExchangeVmoRequest> for SpiImplExchangeVmoRequest
impl FromWireRef<SpiImplExchangeVmoRequest> for SpiImplExchangeVmoRequest
Sourcefn from_wire_ref(wire: &SpiImplExchangeVmoRequest) -> SpiImplExchangeVmoRequest
fn from_wire_ref(wire: &SpiImplExchangeVmoRequest) -> SpiImplExchangeVmoRequest
Converts the given reference to this type.
Sourceimpl PartialEq for SpiImplExchangeVmoRequest
impl PartialEq for SpiImplExchangeVmoRequest
Sourcefn eq(&self, other: &SpiImplExchangeVmoRequest) -> bool
fn eq(&self, other: &SpiImplExchangeVmoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SpiImplExchangeVmoRequest