pub struct SpiImplRegisterVmoRequest {
pub chip_select: u32,
pub vmo_id: u32,
pub vmo: Range,
pub rights: SharedVmoRight,
}Fields
chip_select: u32vmo_id: u32vmo: Rangerights: SharedVmoRightTrait Implementations
Sourceimpl Debug for SpiImplRegisterVmoRequest
impl Debug for SpiImplRegisterVmoRequest
Sourceimpl<___E> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplRegisterVmoRequest>, ___E> for SpiImplRegisterVmoRequest
impl<___E> EncodeOption<Box<'static, SpiImplRegisterVmoRequest>, ___E> for SpiImplRegisterVmoRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplRegisterVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplRegisterVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplRegisterVmoRequest> for SpiImplRegisterVmoRequest
impl FromWire<SpiImplRegisterVmoRequest> for SpiImplRegisterVmoRequest
Sourcefn from_wire(wire: SpiImplRegisterVmoRequest) -> Self
fn from_wire(wire: SpiImplRegisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for SpiImplRegisterVmoRequest
impl PartialEq for SpiImplRegisterVmoRequest
Sourcefn eq(&self, other: &SpiImplRegisterVmoRequest) -> bool
fn eq(&self, other: &SpiImplRegisterVmoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SpiImplRegisterVmoRequest