pub struct SpiImplTransmitVmoRequest {
pub chip_select: u32,
pub buffer: SharedVmoBuffer,
}Fields
chip_select: u32buffer: SharedVmoBufferTrait Implementations
Sourceimpl Clone for SpiImplTransmitVmoRequest
impl Clone for SpiImplTransmitVmoRequest
Sourcefn clone(&self) -> SpiImplTransmitVmoRequest
fn clone(&self) -> SpiImplTransmitVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplTransmitVmoRequest
impl Debug for SpiImplTransmitVmoRequest
Sourceimpl<'a, ___E> Encode<SpiImplTransmitVmoRequest, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplTransmitVmoRequest, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplTransmitVmoRequest>, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplTransmitVmoRequest: Encode<SpiImplTransmitVmoRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SpiImplTransmitVmoRequest>, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplTransmitVmoRequest: Encode<SpiImplTransmitVmoRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a SpiImplTransmitVmoRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplTransmitVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SpiImplTransmitVmoRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplTransmitVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplTransmitVmoRequest>, ___E> for SpiImplTransmitVmoRequest
impl<___E> EncodeOption<Box<'static, SpiImplTransmitVmoRequest>, ___E> for SpiImplTransmitVmoRequest
Sourcefn encode_option(
this: Option<SpiImplTransmitVmoRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplTransmitVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SpiImplTransmitVmoRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplTransmitVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
impl FromWire<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
Sourcefn from_wire(wire: SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
fn from_wire(wire: SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
impl FromWireRef<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
Sourcefn from_wire_ref(wire: &SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
fn from_wire_ref(wire: &SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
Converts the given reference to this type.
Sourceimpl PartialEq for SpiImplTransmitVmoRequest
impl PartialEq for SpiImplTransmitVmoRequest
Sourcefn eq(&self, other: &SpiImplTransmitVmoRequest) -> bool
fn eq(&self, other: &SpiImplTransmitVmoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SpiImplTransmitVmoRequest