#[repr(C)]pub struct SpiImplUnlockBusRequest {
pub chip_select: u32,
}Fields
chip_select: u32Trait Implementations
Sourceimpl Clone for SpiImplUnlockBusRequest
impl Clone for SpiImplUnlockBusRequest
Sourcefn clone(&self) -> SpiImplUnlockBusRequest
fn clone(&self) -> SpiImplUnlockBusRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplUnlockBusRequest
impl Debug for SpiImplUnlockBusRequest
Sourceimpl<'a, ___E> Encode<SpiImplUnlockBusRequest, ___E> for &'a SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplUnlockBusRequest, ___E> for &'a SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnlockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnlockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, SpiImplUnlockBusRequest>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, SpiImplUnlockBusRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnlockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnlockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplUnlockBusRequest>, ___E> for &'a SpiImplUnlockBusRequest
impl<'a, ___E> EncodeOption<Box<'static, SpiImplUnlockBusRequest>, ___E> for &'a SpiImplUnlockBusRequest
Sourcefn encode_option(
this: Option<&'a SpiImplUnlockBusRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplUnlockBusRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SpiImplUnlockBusRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplUnlockBusRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplUnlockBusRequest>, ___E> for SpiImplUnlockBusRequest
impl<___E> EncodeOption<Box<'static, SpiImplUnlockBusRequest>, ___E> for SpiImplUnlockBusRequest
Sourcefn encode_option(
this: Option<SpiImplUnlockBusRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplUnlockBusRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SpiImplUnlockBusRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplUnlockBusRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
impl FromWire<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, SpiImplUnlockBusRequest>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, SpiImplUnlockBusRequest>
Sourcefn from_wire(wire: SpiImplUnlockBusRequest) -> SpiImplUnlockBusRequest
fn from_wire(wire: SpiImplUnlockBusRequest) -> SpiImplUnlockBusRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
impl FromWireRef<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
Sourcefn from_wire_ref(wire: &SpiImplUnlockBusRequest) -> SpiImplUnlockBusRequest
fn from_wire_ref(wire: &SpiImplUnlockBusRequest) -> SpiImplUnlockBusRequest
Converts the given reference to this type.
Sourceimpl Hash for SpiImplUnlockBusRequest
impl Hash for SpiImplUnlockBusRequest
Sourceimpl Ord for SpiImplUnlockBusRequest
impl Ord for SpiImplUnlockBusRequest
Sourcefn cmp(&self, other: &SpiImplUnlockBusRequest) -> Ordering
fn cmp(&self, other: &SpiImplUnlockBusRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SpiImplUnlockBusRequest
impl PartialEq for SpiImplUnlockBusRequest
Sourcefn eq(&self, other: &SpiImplUnlockBusRequest) -> bool
fn eq(&self, other: &SpiImplUnlockBusRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SpiImplUnlockBusRequest
impl PartialOrd for SpiImplUnlockBusRequest
impl Copy for SpiImplUnlockBusRequest
impl Eq for SpiImplUnlockBusRequest
impl StructuralPartialEq for SpiImplUnlockBusRequest