pub struct SpiImplExchangeVectorRequest {
pub chip_select: u32,
pub txdata: Vec<u8>,
}Fields
chip_select: u32txdata: Vec<u8>Trait Implementations
Sourceimpl Clone for SpiImplExchangeVectorRequest
impl Clone for SpiImplExchangeVectorRequest
Sourcefn clone(&self) -> SpiImplExchangeVectorRequest
fn clone(&self) -> SpiImplExchangeVectorRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplExchangeVectorRequest
impl Debug for SpiImplExchangeVectorRequest
Sourceimpl<'a, ___E> Encode<SpiImplExchangeVectorRequest<'static>, ___E> for &'a SpiImplExchangeVectorRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<SpiImplExchangeVectorRequest<'static>, ___E> for &'a SpiImplExchangeVectorRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplExchangeVectorRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplExchangeVectorRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplExchangeVectorRequest<'static>, ___E> for SpiImplExchangeVectorRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<SpiImplExchangeVectorRequest<'static>, ___E> for SpiImplExchangeVectorRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplExchangeVectorRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplExchangeVectorRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplExchangeVectorRequest<'static>>, ___E> for &'a SpiImplExchangeVectorRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplExchangeVectorRequest: Encode<SpiImplExchangeVectorRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SpiImplExchangeVectorRequest<'static>>, ___E> for &'a SpiImplExchangeVectorRequestwhere
___E: Encoder + ?Sized,
&'a SpiImplExchangeVectorRequest: Encode<SpiImplExchangeVectorRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a SpiImplExchangeVectorRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplExchangeVectorRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SpiImplExchangeVectorRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplExchangeVectorRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplExchangeVectorRequest<'static>>, ___E> for SpiImplExchangeVectorRequestwhere
___E: Encoder + ?Sized,
SpiImplExchangeVectorRequest: Encode<SpiImplExchangeVectorRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, SpiImplExchangeVectorRequest<'static>>, ___E> for SpiImplExchangeVectorRequestwhere
___E: Encoder + ?Sized,
SpiImplExchangeVectorRequest: Encode<SpiImplExchangeVectorRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<SpiImplExchangeVectorRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplExchangeVectorRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SpiImplExchangeVectorRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplExchangeVectorRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<SpiImplExchangeVectorRequest<'de>> for SpiImplExchangeVectorRequest
impl<'de> FromWire<SpiImplExchangeVectorRequest<'de>> for SpiImplExchangeVectorRequest
Sourcefn from_wire(
wire: SpiImplExchangeVectorRequest<'de>,
) -> SpiImplExchangeVectorRequest
fn from_wire( wire: SpiImplExchangeVectorRequest<'de>, ) -> SpiImplExchangeVectorRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SpiImplExchangeVectorRequest<'de>> for SpiImplExchangeVectorRequest
impl<'de> FromWireRef<SpiImplExchangeVectorRequest<'de>> for SpiImplExchangeVectorRequest
Sourcefn from_wire_ref(
wire: &SpiImplExchangeVectorRequest<'de>,
) -> SpiImplExchangeVectorRequest
fn from_wire_ref( wire: &SpiImplExchangeVectorRequest<'de>, ) -> SpiImplExchangeVectorRequest
Converts the given reference to this type.
Sourceimpl Hash for SpiImplExchangeVectorRequest
impl Hash for SpiImplExchangeVectorRequest
Sourceimpl Ord for SpiImplExchangeVectorRequest
impl Ord for SpiImplExchangeVectorRequest
Sourcefn cmp(&self, other: &SpiImplExchangeVectorRequest) -> Ordering
fn cmp(&self, other: &SpiImplExchangeVectorRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SpiImplExchangeVectorRequest
impl PartialEq for SpiImplExchangeVectorRequest
Sourcefn eq(&self, other: &SpiImplExchangeVectorRequest) -> bool
fn eq(&self, other: &SpiImplExchangeVectorRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SpiImplExchangeVectorRequest
impl PartialOrd for SpiImplExchangeVectorRequest
impl Eq for SpiImplExchangeVectorRequest
impl StructuralPartialEq for SpiImplExchangeVectorRequest