#[repr(C)]pub struct SpiImplGetChipSelectCountResponse {
pub count: Uint32,
}Expand description
The wire type corresponding to SpiImplGetChipSelectCountResponse.
Fields
count: Uint32Trait Implementations
Sourceimpl Clone for SpiImplGetChipSelectCountResponse
impl Clone for SpiImplGetChipSelectCountResponse
Sourcefn clone(&self) -> SpiImplGetChipSelectCountResponse
fn clone(&self) -> SpiImplGetChipSelectCountResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplGetChipSelectCountResponse
impl Constrained for SpiImplGetChipSelectCountResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SpiImplGetChipSelectCountResponse>,
_: <SpiImplGetChipSelectCountResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SpiImplGetChipSelectCountResponse>, _: <SpiImplGetChipSelectCountResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for SpiImplGetChipSelectCountResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplGetChipSelectCountResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplGetChipSelectCountResponse, ___E> for &'a SpiImplGetChipSelectCountResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplGetChipSelectCountResponse, ___E> for &'a SpiImplGetChipSelectCountResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplGetChipSelectCountResponse, ___E> for SpiImplGetChipSelectCountResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplGetChipSelectCountResponse, ___E> for SpiImplGetChipSelectCountResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplGetChipSelectCountResponse, SpiImplGetChipSelectCountResponse>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplGetChipSelectCountResponse, SpiImplGetChipSelectCountResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SpiImplGetChipSelectCountResponse, ___E> for SpiImplGetChipSelectCountResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<SpiImplGetChipSelectCountResponse, ___E> for SpiImplGetChipSelectCountResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplGetChipSelectCountResponse> for SpiImplGetChipSelectCountResponse
impl FromWire<SpiImplGetChipSelectCountResponse> for SpiImplGetChipSelectCountResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplGetChipSelectCountResponse, SpiImplGetChipSelectCountResponse>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplGetChipSelectCountResponse, SpiImplGetChipSelectCountResponse>
Sourcefn from_wire(
wire: SpiImplGetChipSelectCountResponse,
) -> SpiImplGetChipSelectCountResponse
fn from_wire( wire: SpiImplGetChipSelectCountResponse, ) -> SpiImplGetChipSelectCountResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplGetChipSelectCountResponse> for SpiImplGetChipSelectCountResponse
impl FromWireRef<SpiImplGetChipSelectCountResponse> for SpiImplGetChipSelectCountResponse
Sourcefn from_wire_ref(
wire: &SpiImplGetChipSelectCountResponse,
) -> SpiImplGetChipSelectCountResponse
fn from_wire_ref( wire: &SpiImplGetChipSelectCountResponse, ) -> SpiImplGetChipSelectCountResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplGetChipSelectCountResponse
impl IntoNatural for SpiImplGetChipSelectCountResponse
Sourcetype Natural = SpiImplGetChipSelectCountResponse
type Natural = SpiImplGetChipSelectCountResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplGetChipSelectCountResponse
impl Wire for SpiImplGetChipSelectCountResponse
Sourcetype Narrowed<'de> = SpiImplGetChipSelectCountResponse
type Narrowed<'de> = SpiImplGetChipSelectCountResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>)
fn zero_padding(out_: &mut MaybeUninit<SpiImplGetChipSelectCountResponse>)
Writes zeroes to the padding for this type, if any.