#[repr(C)]pub struct SpiImplRegisterVmoRequest {
pub chip_select: Uint32,
pub vmo_id: Uint32,
pub vmo: Range,
pub rights: SharedVmoRight,
}Expand description
The wire type corresponding to SpiImplRegisterVmoRequest.
Fields
chip_select: Uint32vmo_id: Uint32vmo: Rangerights: SharedVmoRightTrait Implementations
Sourceimpl Constrained for SpiImplRegisterVmoRequest
impl Constrained for SpiImplRegisterVmoRequest
Sourceimpl Debug for SpiImplRegisterVmoRequest
impl Debug for SpiImplRegisterVmoRequest
Sourceimpl<___D> Decode<___D> for SpiImplRegisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SpiImplRegisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequest<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<SpiImplRegisterVmoRequest, ___E> for SpiImplRegisterVmoRequest<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplRegisterVmoRequest> for SpiImplRegisterVmoRequest
impl FromWire<SpiImplRegisterVmoRequest> for SpiImplRegisterVmoRequest
Sourcefn from_wire(wire: SpiImplRegisterVmoRequest) -> Self
fn from_wire(wire: SpiImplRegisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl IntoNatural for SpiImplRegisterVmoRequest
impl IntoNatural for SpiImplRegisterVmoRequest
Sourcetype Natural = SpiImplRegisterVmoRequest
type Natural = SpiImplRegisterVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplRegisterVmoRequest
impl Wire for SpiImplRegisterVmoRequest
Sourcetype Narrowed<'de> = SpiImplRegisterVmoRequest
type Narrowed<'de> = SpiImplRegisterVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.