#[repr(C)]pub struct SpiImplTransmitVmoRequest {
pub chip_select: Uint32,
pub buffer: SharedVmoBuffer,
}Expand description
The wire type corresponding to SpiImplTransmitVmoRequest.
Fields
chip_select: Uint32buffer: SharedVmoBufferTrait Implementations
Sourceimpl Clone for SpiImplTransmitVmoRequest
impl Clone for SpiImplTransmitVmoRequest
Sourcefn clone(&self) -> SpiImplTransmitVmoRequest
fn clone(&self) -> SpiImplTransmitVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplTransmitVmoRequest
impl Constrained for SpiImplTransmitVmoRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SpiImplTransmitVmoRequest>,
_: <SpiImplTransmitVmoRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SpiImplTransmitVmoRequest>, _: <SpiImplTransmitVmoRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SpiImplTransmitVmoRequest
impl Debug for SpiImplTransmitVmoRequest
Sourceimpl<___D> Decode<___D> for SpiImplTransmitVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplTransmitVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplTransmitVmoRequest, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplTransmitVmoRequest, ___E> for &'a SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<SharedVmoBuffer, ___E>,
impl<___E, T0, T1> Encode<SpiImplTransmitVmoRequest, ___E> for SpiImplTransmitVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<SharedVmoBuffer, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
impl FromWire<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
Sourcefn from_wire(wire: SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
fn from_wire(wire: SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
impl FromWireRef<SpiImplTransmitVmoRequest> for SpiImplTransmitVmoRequest
Sourcefn from_wire_ref(wire: &SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
fn from_wire_ref(wire: &SpiImplTransmitVmoRequest) -> SpiImplTransmitVmoRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplTransmitVmoRequest
impl IntoNatural for SpiImplTransmitVmoRequest
Sourcetype Natural = SpiImplTransmitVmoRequest
type Natural = SpiImplTransmitVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplTransmitVmoRequest
impl Wire for SpiImplTransmitVmoRequest
Sourcetype Narrowed<'de> = SpiImplTransmitVmoRequest
type Narrowed<'de> = SpiImplTransmitVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>)
fn zero_padding(out_: &mut MaybeUninit<SpiImplTransmitVmoRequest>)
Writes zeroes to the padding for this type, if any.