#[repr(C)]pub struct SpiImplUnregisterVmoRequest {
pub chip_select: Uint32,
pub vmo_id: Uint32,
}Expand description
The wire type corresponding to SpiImplUnregisterVmoRequest.
Fields
chip_select: Uint32vmo_id: Uint32Trait Implementations
Sourceimpl Clone for SpiImplUnregisterVmoRequest
impl Clone for SpiImplUnregisterVmoRequest
Sourcefn clone(&self) -> SpiImplUnregisterVmoRequest
fn clone(&self) -> SpiImplUnregisterVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplUnregisterVmoRequest
impl Constrained for SpiImplUnregisterVmoRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SpiImplUnregisterVmoRequest>,
_: <SpiImplUnregisterVmoRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SpiImplUnregisterVmoRequest>, _: <SpiImplUnregisterVmoRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SpiImplUnregisterVmoRequest
impl Debug for SpiImplUnregisterVmoRequest
Sourceimpl<___D> Decode<___D> for SpiImplUnregisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplUnregisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplUnregisterVmoRequest, ___E> for &'a SpiImplUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplUnregisterVmoRequest, ___E> for &'a SpiImplUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplUnregisterVmoRequest, ___E> for SpiImplUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplUnregisterVmoRequest, ___E> for SpiImplUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplUnregisterVmoRequest, SpiImplUnregisterVmoRequest>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplUnregisterVmoRequest, SpiImplUnregisterVmoRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<SpiImplUnregisterVmoRequest, ___E> for SpiImplUnregisterVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<SpiImplUnregisterVmoRequest, ___E> for SpiImplUnregisterVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplUnregisterVmoRequest> for SpiImplUnregisterVmoRequest
impl FromWire<SpiImplUnregisterVmoRequest> for SpiImplUnregisterVmoRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplUnregisterVmoRequest, SpiImplUnregisterVmoRequest>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplUnregisterVmoRequest, SpiImplUnregisterVmoRequest>
Sourcefn from_wire(wire: SpiImplUnregisterVmoRequest) -> SpiImplUnregisterVmoRequest
fn from_wire(wire: SpiImplUnregisterVmoRequest) -> SpiImplUnregisterVmoRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplUnregisterVmoRequest> for SpiImplUnregisterVmoRequest
impl FromWireRef<SpiImplUnregisterVmoRequest> for SpiImplUnregisterVmoRequest
Sourcefn from_wire_ref(
wire: &SpiImplUnregisterVmoRequest,
) -> SpiImplUnregisterVmoRequest
fn from_wire_ref( wire: &SpiImplUnregisterVmoRequest, ) -> SpiImplUnregisterVmoRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplUnregisterVmoRequest
impl IntoNatural for SpiImplUnregisterVmoRequest
Sourcetype Natural = SpiImplUnregisterVmoRequest
type Natural = SpiImplUnregisterVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplUnregisterVmoRequest
impl Wire for SpiImplUnregisterVmoRequest
Sourcetype Narrowed<'de> = SpiImplUnregisterVmoRequest
type Narrowed<'de> = SpiImplUnregisterVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>)
fn zero_padding(out_: &mut MaybeUninit<SpiImplUnregisterVmoRequest>)
Writes zeroes to the padding for this type, if any.